@@ -5,7 +5,7 @@ use Mojolicious::Plugin::Vparam::Common qw(:all);
 use version;
 use List::MoreUtils qw(firstval natatime mesh);
 
-our $VERSION    = '2.08';
+our $VERSION    = '2.09';
 
 # Regext for shortcut parser
 our $SHORTCUT_REGEXP = qr{
@@ -450,19 +450,22 @@ sub register {
             $self->verror( $name, %attr, message => 'Empty hash' )
                 if $attr{hash} and not $attr{optional} and not @input;
 
+            # Rename for model
+            my $as = $attr{as} // $name;
+
             if( $attr{hash} ) {
-                $result{ $name } = { mesh @keys, @output };
+                $result{ $as } = { mesh @keys, @output };
             } elsif( $attr{array} ) {
-                $result{ $name } = defined $attr{multijoin}
+                $result{ $as } = defined $attr{multijoin}
                     ? join $attr{multijoin}, @output
                     : \@output
                 ;
             } else {
-                $result{ $name } = $output[0]
+                $result{ $as } = $output[0]
                     unless $attr{skipundef} and not defined($output[0]);
             }
             # Mojolicious::Validator::Validation
-            $self->validation->output->{$name} = $result{ $name }
+            $self->validation->output->{$name} = $result{ $as }
                 if $conf->{mojo_validator};
         }
 
@@ -493,7 +496,7 @@ sub register {
             $result = $self->vparams( $name => { type   => $def, %attr } );
         }
 
-        return $result->{$name};
+        return $result->{ $attr{as} // $name };
     });
 
     # Load extensions: types, filters etc.
@@ -715,7 +718,7 @@ Get parameter error string. Return 0 if no error.
 
 =head2 verrors
 
-Return erorrs count in scalar context. In list context return erorrs hash.
+Return errors count in scalar context. In list context return errors hash.
 
     # List context get hash
     my %errors = $self->verrors;
@@ -1175,6 +1178,16 @@ Parameter type. If set then some filters will be apply. See L</TYPES>.
 
 After the application of the type used filters.
 
+=head2 as
+
+Rename output key for I<vparams> to simple use in models.
+
+    # Return {login => '...', password => '...'}
+    $self->vparams(
+        myparam1 => {type => 'str', as => 'login'},
+        myparam2 => {type => 'str', as => 'password'},
+    );
+
 =head2 array
 
 Force value will array. Default: false.
@@ -1404,34 +1417,6 @@ Set default I<skipundef> flag for all params in L</vparams> and L</vsort>.
 
 Filters are used in conjunction with types for additional verification.
 
-=head2 min
-
-Check minimum parameter value.
-
-    # Error if myparam less than 10
-    $self->vparam(myparam => 'int', min => 10);
-
-=head2 max
-
-Check maximum parameter value.
-
-    # Error if myparam greater than 100
-    $self->vparam(myparam => 'int', max => 100);
-
-=head2 equal
-
-Check parametr equal.
-
-    # Error if myparam not equal 100
-    $self->vparam(myparam => 'int', equal => 100);
-
-=head2 not
-
-Check parametr not equal.
-
-    # Error if myparam equal 100
-    $self->vparam(myparam => 'int', not => 100);
-
 =head2 range
 
 Check parameter value to be in range.
@@ -1460,9 +1445,13 @@ Check maximum length in utf8.
     # Error if value is an empty string
     $self->vparam(myparam => 'str', size => [1, 100]);
 
-=head2 String comparations
+=head2 Numbers comparation
 
-    I<lt>, I<gt>, I<le>, I<ge>, I<cmp>, I<eq>, I<ne>
+I<min>, I<max>, I<equal>, I<not>
+
+=head2 Strings comparation
+
+I<lt>, I<gt>, I<le>, I<ge>, I<cmp>, I<eq>, I<ne>
 
 =head1 RESTRICTIONS
 
